==> qtah-qt5-0.3.0.tar.gz: qtah-qt5-0.3.0/src/Graphics/UI/Qtah/Widgets/QGroupBox.hs <==
{-# LANGUAGE CPP, FlexibleContexts, FlexibleInstances, GeneralizedNewtypeDeriving, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
#if !MIN_VERSION_base(4,8,0)
{-# LANGUAGE OverlappingInstances #-}
#endif

---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QGroupBox (
  QGroupBoxValue (..),
  QGroupBoxConstPtr (..),
  QGroupBoxPtr (..),
  QGroupBoxConst,
  QGroupBox,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  newWithTitle,
  newWithTitleAndParent,
  alignment,
  isCheckable,
  isChecked,
  isFlat,
  setAlignment,
  setCheckable,
  setChecked,
  setFlat,
  setTitle,
  title,
  clickedSignal,
  toggledSignal,
  ) where

import Graphics.UI.Qtah.Generated.Widgets.QGroupBox
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude ()
import qualified Prelude as HoppyP


castConst = toQGroupBoxConst
cast = toQGroupBox
downCastConst = downToQGroupBoxConst
downCast = downToQGroupBox

clickedSignal :: (QGroupBoxPtr object) => QtahSignal.Signal object (HoppyP.Bool -> HoppyP.IO ())
clickedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerBool_new fn'
    listenerBool_connectListener listener' object' "2clicked(bool)"
  , QtahSignal.internalName = "QGroupBox::clicked (ListenerBool)"
  }

toggledSignal :: (QGroupBoxPtr object) => QtahSignal.Signal object (HoppyP.Bool -> HoppyP.IO ())
toggledSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerBool_new fn'
    listenerBool_connectListener listener' object' "2toggled(bool)"
  , QtahSignal.internalName = "QGroupBox::toggled (ListenerBool)"
  }

==> qtah-qt5-0.8.0.tar.gz: qtah-qt5-0.8.0/src/Graphics/UI/Qtah/Widgets/QGroupBox.hs <==
{-# LANGUAGE FlexibleContexts, FlexibleInstances, ForeignFunctionInterface, MonoLocalBinds, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QGroupBox (
  QGroupBoxValue (..),
  QGroupBoxConstPtr (..),
  QGroupBoxPtr (..),
  QGroupBoxConst,
  QGroupBox,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  newWithTitle,
  newWithTitleAndParent,
  alignment,
  emitClicked,
  emitToggled,
  isCheckable,
  isChecked,
  isFlat,
  setAlignment,
  setCheckable,
  setChecked,
  setFlat,
  setTitle,
  title,
  clickedSignal,
  toggledSignal,
  ) where

import qualified Foreign.Hoppy.Runtime as QtahFHR
import Graphics.UI.Qtah.Generated.Widgets.QGroupBox
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude (($), (>>))
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQGroupBoxConst
cast = toQGroupBox
downCastConst = downToQGroupBoxConst
downCast = downToQGroupBox

clickedSignal :: (QGroupBoxPtr object) => QtahSignal.Signal object (HoppyP.Bool -> HoppyP.IO ())
clickedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerBool_new object' "2clicked(bool)" fn'
    valid' <- listenerBool_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QGroupBox::clicked (ListenerBool)"
  }

toggledSignal :: (QGroupBoxPtr object) => QtahSignal.Signal object (HoppyP.Bool -> HoppyP.IO ())
toggledSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerBool_new object' "2toggled(bool)" fn'
    valid' <- listenerBool_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QGroupBox::toggled (ListenerBool)"
  }
